'''A Python module for interacting with CoreData

Call coredata.int32 (name), coredata.string (name), etc., which
return Datum objects that have get () and set () methods.'''

# References:
#  http://dbus.freedesktop.org/doc/dbus-python/doc/tutorial.html

import dbus
import dbus.mainloop.glib
from gi.repository import GObject as gobject

class MainLoop:
    '''The main loop must be created before creating a connection.'''
    def __init__ (self):
        dbus.mainloop.glib.DBusGMainLoop (set_as_default=True)

    def run (self):
        loop = gobject.MainLoop ()
        loop.run ();

loop = MainLoop ()
connection = dbus.bus.BusConnection ("unix:path=/tmp/coredata-dbus")

class _Datum:
    def __init__ (self, name):
        self.proxy = connection.get_object ('com.forceamerica.CoreData', '/com/forceamerica/CoreData/Datum/' + name)
        self.name = name

    def get (self):
        return self.iface.Read ()

    def set (self, value):
        return self.iface.Write (value)

    def onChanged (self, callable):
        self.handler = callable
        self.iface.connect_to_signal ('Changed', self.callHandler)

    def callHandler (self, args):
        self.handler (self, args)

class _StringDatum (_Datum):
    def __init__ (self, name):
        _Datum.__init__ (self, name)
        self.iface = dbus.Interface (self.proxy, dbus_interface="com.forceamerica.CoreData.StringDatum")

def string (name):
    return _StringDatum (name)

class _Int32Datum (_Datum):
    def __init__ (self, name):
        _Datum.__init__ (self, name)
        self.iface = dbus.Interface (self.proxy, dbus_interface="com.forceamerica.CoreData.Int32Datum")

def int32 (name):
    return _Int32Datum (name)

class _TimestampedInt32Datum (_Datum):
    def __init__ (self, name):
        _Datum.__init__ (self, name)
        self.iface = dbus.Interface (self.proxy, dbus_interface="com.forceamerica.CoreData.TimestampedInt32Datum")

def timestamped_int32 (name):
    return _TimestampedInt32Datum (name)

class _BoolDatum (_Datum):
    def __init__ (self, name):
        _Datum.__init__ (self, name)
        self.iface = dbus.Interface (self.proxy, dbus_interface="com.forceamerica.CoreData.BoolDatum")

def bool (name):
    return _BoolDatum (name)

class _DoubleDatum (_Datum):
    def __init__ (self, name):
        _Datum.__init__ (self, name)
        self.iface = dbus.Interface (self.proxy, dbus_interface="com.forceamerica.CoreData.DoubleDatum")

def double (name):
    return _DoubleDatum (name)

class _FileCommand (_Datum):
    def __init__ (self, name):
        _Datum.__init__ (self, name)
        self.iface = dbus.Interface (self.proxy, dbus_interface="com.forceamerica.CoreData.FileCommandDatum")

def file_command (name):
    return _FileCommand (name)

class _RegisteredDeviceList (_Datum):
    def __init__ (self, name):
        _Datum.__init__ (self, name)
        self.iface = dbus.Interface (self.proxy, dbus_interface="com.forceamerica.CoreData.RegisteredDeviceListDatum")

def registered_devices (name):
    return _RegisteredDeviceList (name)

class _StringIntMap (_Datum):
    def __init__ (self, name):
        _Datum.__init__ (self, name)
        self.iface = dbus.Interface (self.proxy, dbus_interface="com.forceamerica.CoreData.StringIntMapDatum")

def string_int_map (name):
    return _StringIntMap (name)

class _ProportionalOutputMap (_Datum):
    def __init__ (self, name):
        _Datum.__init__ (self, name)
        self.iface = dbus.Interface (self.proxy, dbus_interface="com.forceamerica.CoreData.ProportionalOutputMapDatum")

def prop_output_map (name):
    return _ProportionalOutputMap (name)

class _ByteBlock (_Datum):
    def __init__ (self, name):
        _Datum.__init__ (self, name)
        self.iface = dbus.Interface (self.proxy, dbus_interface="com.forceamerica.CoreData.ByteBlockDatum")

def byte_block (name):
    return _ByteBlock (name)

class _LinearAnalogSensorList (_Datum):
    def __init__ (self, name):
        _Datum.__init__ (self, name)
        self.iface = dbus.Interface (self.proxy, dbus_interface="com.forceamerica.CoreData.LinearAnalogSensorInfoListDatum")

def linear_analog_sensors (name):
    return _LinearAnalogSensorList (name)
