#!/bin/sh

####################################################################
#  File Name:    ethernet_test.sh
#  Description:  A production test that guarantees that the ethernet
#                port has been installed properly.
#  Copyright:    (c) 2010 Force America, Inc.
#  Created:      11/30/2010 By Andrew Dorney
####################################################################

# Print out a header.
echo "FORCE America SSC6100 Ethernet Test Script"
echo "Version 1.0"
echo "=========================================="
echo ""

LSMOD=$(lsmod | grep e100)

# If it's not already loaded, load the module for the SSC6100 SBC's 
# Ethernet device.
if [[ -z "$LSMOD" ]]; then
	modprobe e100
	if [[ $? != 0 ]]; then
		echo ""
		echo "FAILURE - Unable to load e100 driver."
		exit 1
	fi
fi

# Load the interface.
ifconfig eth0 up
if [[ $? != 0 ]]; then
    echo ""
    echo "FAILURE - Unable to load eth0 interface."
	# Remove the driver from memory.
	modprobe -r e100
    exit 1
fi

# Get an IP address via DHCP.
dhclient eth0
if [[ $? != 0 ]]; then
    echo ""
    echo "FAILURE - Unable to receive IP address from DHCP server."
	# Disable the interface.
	ifconfig eth0 down
	# Remove the driver from memory.
	modprobe -r e100
    exit 1
fi

# Ping Google.
ping -c5 www.google.com
if [[ $? != 0 ]]; then
    echo ""
    echo "FAILURE - Unable to ping www.forceamerica.com."
	# Disable the interface.
	ifconfig eth0 down
	# Remove the driver from memory.
	modprobe -r e100
	exit 1
fi

# Disable the interface.
ifconfig eth0 down
# Remove the driver from memory.
modprobe -r e100

echo ""
echo "SUCCESS - The ethernet device is installed properly."
exit 0
