#!/bin/bash

#
###############################################################################
# Filename: /usr/local/sbin/find_upgrades.sh
# Source: P1131
# Version: 0.04
# Copyright: (c) 2008 Force America, Inc.
#
# Description:
# This is a shell script that sits on the 6100 system and is run when the user
# adds a USB hard disk (or flash device) to the system. The udev script (located 
# at /etc/udev/rules.d/050_forceamerica_usb_update.rules) will run this script
# and pass in either add or remove. On an add, we'll tell the Calibration menu
# that we have updates (if they exist), and on a remove, we'll tell the
# Calibration menu that we don't have any updates.
#
# This script only handles update detection and does not do any of the 
# heavy lifting.
#
# Created: 08/15/2008 By Andrew Dorney (P1131)
# Modified: 10/14/2008 By Andrew Dorney (P1131)
###############################################################################
#




DEVICE_STATUS=$1  # Set DEVICE_STATUS to either add or remove, depending on what was passed to the script.
DATE=$(/bin/date)  # The output of the /bin/date command
LOG=/var/log/6100_software_update.log

if [[ "$DEVICE_STATUS" == "add" ]]  # The device has been plugged in.
	then
	# Sleep for 1 second so Linux can recognize the flash device.
	sleep 1

	if [[ ! -e /media/disk ]]
	then
		mkdir /media/disk
	fi

	if [[ -e /dev/usbdisk ]]
	then
		/bin/mount /dev/usbdisk /media/disk >> $LOG 2>&1
		
		# Sleep 2 seconds so Linux has time to mount the drive 
		# before writing to it.
		sleep 2
		
		# If the output of a file listing, searching for our upgrades, is not null, tell the calib menu.
		if [[ -n "$(ls /media/disk | grep 'K.*_6100_Version_.*_.*_.*.upgrade')" ]]
		then
			echo "Upgrade detected" >> $LOG
			/6100/rc/pyclient set bool UpgradesDetected 1 >> $LOG 2>&1
		else
			echo "Upgrade not found" >> $LOG
			/6100/rc/pyclient set bool UpgradesDetected "" >> $LOG 2>&1
		fi
		
		# Unmount the drive.
		/bin/umount /media/disk
		
	else
		# Record the fact that the drive doesn't exist.
		echo "USB hard drive requested, but not mounted on" $DATE >> $LOG
	fi

elif [[ "$DEVICE_STATUS" == "remove" ]]  # The device has been removed.
then
	echo "USB removed" >> $LOG
	# Tell the calib menu that there are no upgrades.	
	/6100/rc/pyclient set bool UpgradesDetected "" >> $LOG 2>&1
else
	echo "Unknown find_upgrades.sh parameter." >> $LOG	
fi
