--------------------------------------------------------------------------------
-- (c) 2020 Force America, Inc
-- Upgrades a revision 11 database to revision 12
--------------------------------------------------------------------------------

BEGIN TRANSACTION;

ALTER TABLE snapshot ADD COLUMN dust_control_unload_time_hms TEXT;
ALTER TABLE snapshot ADD COLUMN herbicide_unload_time_hms TEXT;

CREATE TABLE dust_control_material
(
    snapshot_id                  INTEGER REFERENCES snapshot(snapshot_id),
    name                         TEXT,
    -- data totals to store
    dust_control_distance_km     REAL,
    dust_control_volume_l        REAL,
    dust_control_time_closed_hms TEXT,
    dust_control_time_open_hms   TEXT,
    dust_control_time_manual_hms TEXT,
    dust_control_time_blast_hms  TEXT,
    CONSTRAINT dust_control_pk
        PRIMARY KEY (snapshot_id, name)
        ON CONFLICT ROLLBACK
);

CREATE TABLE herbicide_material
(
    snapshot_id               INTEGER REFERENCES snapshot(snapshot_id),
    name                      TEXT,
    -- data totals to store
    herbicide_distance_km     REAL,
    herbicide_volume_l        REAL,
    herbicide_time_closed_hms TEXT,
    herbicide_time_open_hms   TEXT,
    herbicide_time_manual_hms TEXT,
    herbicide_time_blast_hms  TEXT,
    CONSTRAINT herbicide_pk
        PRIMARY KEY (snapshot_id, name)
        ON CONFLICT ROLLBACK
);

-- Delete and remake the table to ensure the it only contains the new value.
DROP TABLE meta;

CREATE TABLE meta
(
    snapshot_schema_version    INTEGER
);

INSERT INTO meta(snapshot_schema_version) VALUES (12);

COMMIT TRANSACTION;
